@@ -12,6 +12,7 @@ use Net::Ping::External qw(ping);
 $loaded = 1;
 print "ok 1\n";
 
+$Net::Ping::External::DEBUG_OUTPUT = 1;
 ######################### End of black magic.
 
 # Insert your test code below (better if it prints "ok 13"
@@ -31,6 +32,10 @@ print "ok 1\n";
 push @passed, 1 if $loaded;
 push @failed, 1 unless $loaded;
 
+my $output_test_2;
+my $exit_test_2;
+my $error_test_2;
+
 eval { $ret = ping(host => '127.0.0.1') };
 if (!$@ && $ret) {
   print "ok 2\n";
@@ -39,6 +44,11 @@ if (!$@ && $ret) {
 else {
   print "not ok 2\n";
   push @failed, 2;
+  $output_test_2 = $Net::Ping::External::LAST_OUTPUT;
+  $exit_test_2 = $Net::Ping::External::LAST_EXIT_CODE;
+  if ($@) {
+    $error_test_2 = $@;
+  }
 }
 
 eval { $ret = ping(host => '127.0.0.1', timeout => 5) };
@@ -114,19 +124,36 @@ if (@failed) {
 my @output = `$^X -v`;
 my $a='';
 $a.= "\nOperating system according to perl: ".$^O."\n";
-$a.= "Operating system according to `uname -a` (if available):\n";
-$a.= `uname -a`;
+if ($^O ne 'MSWin32') {
+  $a.= "Operating system according to `uname -a` (if available):\n";
+  $a.= `uname -a`;
+}
 $a.= "Perl version: ";
 $a.= @output[1..1];
+if ($^O ne 'MSWin32') {
+  $a.= "Ping location: ".`which ping`;
+}
 $a.= "Ping help: ";
 my $ping=($^O eq 'Netbsd'?Net::Ping::External::_locate_ping_netbsd():'ping');
-$a.= `$ping 2>&1`;
+my $usage='';
+if ($^O eq 'gnukfreebsd') {
+  $usage = '--help';
+}
+$a.= `$ping $usage 2>&1`;
 $a.="\n";
 if (@failed and $failed[0]==5 and lc($^O) eq 'linux') {
  $a.="-\nping -c 1 some.non.existent.host\n";
  $a.=`ping -c 1 some.non.existent.host`;
  $a.="\n-\n";
 }
+if (@failed and $failed[0]==2) {
+ $a.="-\nresults for test 2:\n";
+ $a.="exit code for test 2: $exit_test_2\n";
+ $a.="output for test 2: $output_test_2" if defined $output_test_2;
+ $a.="\$\@ for test 2: $error_test_2" if $error_test_2;
+ $a.="\n-\n";
+}
+
 open A,'>NPE.out';
 print A $a;
 close A;
